@@ -164,11 +164,11 @@ class DynamoUpdateExpressionSetActionValueFactory:
         self.expression_attributes.merge_expression_attributes(**vars(value.expression_attributes))
 
     def set_if_not_exists(self, path: str, value: DynamoUpdateExpressionSetActionValueObject):
-        """Create the operand expression to check if the set exists
+        """Create the operand expression that does not update if the attribute exists
 
         Args:
-            path (str):
-            value (DynamoUpdateExpressionSetActionValueObject):
+            path (str): The attribute path
+            value (DynamoUpdateExpressionSetActionValueObject): value to update to
         """
         self.__error_if_modified()
         self.__merge_expression_attributes(value)
@@ -208,6 +208,16 @@ class DynamoUpdateExpressionSetActionValueFactory:
         self.__operand_expression += f" {operator.value} {value.operand_expression}"
         self.__set_modified()
 
+    def add_path(self, path: str):
+        """Adds a path to the operand expression (for arithmetic operations)
+
+        Args:
+            path (str): The path of the attribute
+        """
+        self.__error_if_modified()
+        exp_attr_str = self.expression_attributes.set_expression_attribute_name(path)
+        self.__operand_expression += f" {exp_attr_str}"
+
     def add_by_expression_value(self, value: DynamoUpdateExpressionSetActionValueObject):
         """Add by arithmetic operation using the given operator and value
 
