@@ -83,6 +83,7 @@ def get_aws_lambda_body_kwarg_mapper(kwarg_name: str) -> KwargMapper:
     Returns:
         (KwargMapper) The mapper for this kwarg
     """
+
     def __kwarg_mapper(*args) -> Tuple[str, Any]:
         return kwarg_name, aws_lambda_body_arg_mapper(*args)
 
@@ -98,6 +99,7 @@ def get_aws_lambda_path_param_arg_mapper(path_param_name: str) -> ArgMapper:
     Returns:
         (ArgMapper) The mapper for this path param arg
     """
+
     def __arg_mapper(*args) -> Any:
         return __get_path_parameter(__get_event_from_args(*args), path_param_name)
 
@@ -114,12 +116,38 @@ def get_aws_lambda_path_param_kwarg_mapper(kwarg_name: str, path_param_name: str
     Returns:
         (KwargMapper) The mapper for this path param kwarg
     """
+
     def __kwarg_mapper(*args) -> Tuple[str, Any]:
         return kwarg_name, get_aws_lambda_path_param_arg_mapper(path_param_name)(*args)
 
     return __kwarg_mapper
 
 
+def __get_auth_context(*args) -> dict:
+    """Get the Authorizer context
+
+    Args:
+        *args: the args from the handler
+
+    Returns:
+        (dict) The authorizer context dictionary
+    """
+    return __get_event_from_args(*args)["requestContext"]["authorizer"]
+
+
+def get_aws_auth_context_arg_mapper() -> ArgMapper:
+    """Get an arg mapper that provides the entire Authorizer context
+
+    Returns:
+        (ArgMapper) The mapper for the Authorizer context
+    """
+
+    def __arg_mapper(*args) -> dict:
+        return __get_auth_context(*args)
+
+    return __arg_mapper
+
+
 def __get_auth_context_item(item_key: str, *args) -> Any:
     """Get a specified item from the Authorizer context
 
@@ -130,7 +158,7 @@ def __get_auth_context_item(item_key: str, *args) -> Any:
     Returns:
         (Any) The value of the authorizer context for the specified key
     """
-    auth_context = __get_event_from_args(*args)["requestContext"]["authorizer"]
+    auth_context = __get_auth_context(*args)
     return auth_context[item_key]
 
 
